@@ -3,6 +3,7 @@ mod node;
 mod persistent_node;
 
 pub use self::{
-    lazy_node::LazyNode, node::Node,// persistent_node::persistent_node,
+    lazy_node::LazyNode,
+    node::Node, // persistent_node::persistent_node,
     persistent_node::PersistentNode,
 };
